@@ -7,8 +7,11 @@ import (
 	"os"
 	"os/user"
 	"regexp"
+	"strconv"
 	"strings"
 
+	go_ora "github.com/sijms/go-ora/v2"
+
 	"github.com/danvergara/dblab/pkg/command"
 	"github.com/danvergara/dblab/pkg/drivers"
 )
@@ -20,9 +23,16 @@ var (
 	// in the system to be used as database username.
 	ErrCantDetectUSer = errors.New("could not detect default username")
 	// ErrInvalidPostgresURLFormat is the error used to notify that the postgres given url is not valid.
-	ErrInvalidPostgresURLFormat = errors.New("invalid url - valid format: postgres://user:password@host:port/db?sslmode=mode")
+	ErrInvalidPostgresURLFormat = errors.New(
+		"invalid url - valid format: postgres://user:password@host:port/db?sslmode=mode",
+	)
 	// ErrInvalidMySQLURLFormat is the error used to notify that the given mysql url is not valid.
-	ErrInvalidMySQLURLFormat = errors.New("invalid url - valid format: mysql://user:password@tcp(host:port)/db")
+	ErrInvalidMySQLURLFormat = errors.New(
+		"invalid url - valid format: mysql://user:password@tcp(host:port)/db",
+	)
+	ErrInvalidOracleURLFormat = errors.New(
+		"invalid url - valid format: oracle://user:pass@server/service_name",
+	)
 	// ErrInvalidURLFormat is used to notify the url is invalid.
 	ErrInvalidURLFormat = errors.New("invalid url")
 	// ErrInvalidDriver is used to notify that the provided driver is not supported.
@@ -33,6 +43,8 @@ var (
 	ErrSocketFileDoNotExist = errors.New("socket file does not exist")
 	// ErrInvalidSocketFile indicates that the socket file must end with .sock as suffix.
 	ErrInvalidSocketFile = errors.New("invalid socket file - must end with .sock")
+	// ErrInvalidOraclePort indicates that the port passed is not a proper integer.
+	ErrInvalidOraclePort = errors.New("invalid oracle port")
 )
 
 func init() {
@@ -63,9 +75,16 @@ func BuildConnectionFromOpts(opts command.Options) (string, command.Options, err
 		// this options is for sqlite.
 		// For more information see https://github.com/mattn/go-sqlite3#connection-string.
 		if strings.HasPrefix(opts.URL, "file:") {
+			opts.Driver = drivers.Oracle
 			return opts.URL, opts, nil
 		}
 
+		if strings.HasPrefix(opts.URL, "oracle:") {
+			opts.Driver = drivers.Oracle
+			conn, err := formatOracleURL(opts)
+			return conn, opts, err
+		}
+
 		return "", opts, fmt.Errorf("%s: %w", opts.URL, ErrInvalidURLFormat)
 	}
 
@@ -77,6 +96,40 @@ func BuildConnectionFromOpts(opts command.Options) (string, command.Options, err
 	}
 
 	switch opts.Driver {
+	case drivers.Oracle:
+		iPort, err := strconv.Atoi(opts.Port)
+		if err != nil {
+			return "", opts, fmt.Errorf("%v : %w", err, ErrInvalidPostgresURLFormat)
+		}
+
+		urloptions := make(map[string]string)
+
+		if opts.SSL != "" {
+			urloptions["SSL"] = opts.SSL
+		}
+
+		if opts.SSLVerify != "" {
+			urloptions["SSL Verify"] = opts.SSLVerify
+		}
+
+		if opts.TraceFile != "" {
+			urloptions["TRACE FILE"] = opts.TraceFile
+		}
+
+		if opts.Wallet != "" {
+			urloptions["wallet"] = url.QueryEscape(opts.Wallet)
+		}
+
+		connStr := go_ora.BuildUrl(
+			opts.Host,
+			iPort,
+			opts.DBName,
+			opts.User,
+			opts.Pass,
+			urloptions,
+		)
+
+		return connStr, opts, nil
 	case drivers.Postgres:
 		query := url.Values{}
 		if opts.Socket != "" {
@@ -261,6 +314,31 @@ func formatMySQLURL(opts command.Options) (string, error) {
 	return uri.String(), nil
 }
 
+// formatOracleURL returns valid uri for oracle connection.
+func formatOracleURL(opts command.Options) (string, error) {
+	if !hasValidOraclePrefix(opts.URL) {
+		return "", fmt.Errorf("invalid prefix %s : %w", opts.URL, ErrInvalidOracleURLFormat)
+	}
+
+	uri, err := url.Parse(opts.URL)
+	if err != nil {
+		return "", fmt.Errorf("%v : %w", err, ErrInvalidOracleURLFormat)
+	}
+
+	result := map[string]string{}
+	for k, v := range uri.Query() {
+		result[strings.ToLower(k)] = v[0]
+	}
+
+	query := url.Values{}
+	for k, v := range result {
+		query.Add(k, v)
+	}
+	uri.RawQuery = query.Encode()
+
+	return uri.String(), nil
+}
+
 // validates if dsn pattern match with the parameter.
 func parseDSN(dsn string) (string, error) {
 	matches := dsnPattern.FindStringSubmatch(dsn)
@@ -286,8 +364,15 @@ func hasValidMySQLPrefix(rawurl string) bool {
 	return strings.HasPrefix(rawurl, "mysql://")
 }
 
+// hasValidOraclePrefix checks if a given url has the driver name in it.
+func hasValidOraclePrefix(rawurl string) bool {
+	return strings.HasPrefix(rawurl, "oracle://")
+}
+
 func hasValidSqlite3FileExtension(fileName string) bool {
-	return strings.HasSuffix(fileName, "sqlite") || strings.HasSuffix(fileName, "db") || strings.HasSuffix(fileName, "db3") || strings.HasSuffix(fileName, "sqlite3")
+	return strings.HasSuffix(fileName, "sqlite") || strings.HasSuffix(fileName, "db") ||
+		strings.HasSuffix(fileName, "db3") ||
+		strings.HasSuffix(fileName, "sqlite3")
 }
 
 func socketFileExists(socketFile string) bool {
